@@ -1,6 +1,11 @@
 import ctypes
+import string
 import typing
 import json
+import uuid
+import enum
+import dataclasses
+import orjson
 
 
 class BLF_ObjectType(object):
@@ -143,7 +148,35 @@ class BLF_ObjectType(object):
     ETH_SOMEIP = 143    # 解析后的 someip 报文
     ETH_SOMEIP_SD = 144 # 解析后的 SD
 
-    
+class BlfLogInfo(ctypes.Structure):
+    _fields_ = [
+        ('file_path', ctypes.c_char*128),
+        ("is_open", ctypes.c_bool),
+        ("counter", ctypes.c_uint64),
+        ]
+    def __init__(
+        self,
+        file_path:str,
+        is_open:bool,
+        counter:int) -> None:
+        '''
+        描述一个 BLFIO 的记录状态
+        '''
+        super().__init__()
+        self.file_path = ctypes.create_string_buffer(file_path.encode('utf-8'))
+        self.is_open = ctypes.c_bool(is_open)
+        self.counter = ctypes.c_uint64(counter)
+
+    # def __str__(self) -> str:
+        # return super().__str__()
+        # s_ = 
+    def ToDict(self) -> dict:
+        return {
+            'file_path': self.file_path.decode('utf-8') if (isinstance(self.file_path, bytes)) else self.file_path,
+            'is_open': self.is_open,
+            'counter': int.from_bytes(self.counter, byteorder='big', signed=False) if (isinstance(self.counter, bytes)) else self.counter
+        }
+
 class BlfIoStruct(ctypes.Structure):
     def __init__(self) -> None:
         super().__init__()
@@ -163,7 +196,8 @@ class BlfIoStruct(ctypes.Structure):
         '''
         序列化为 bytes
         '''
-        return self._blfObjType.to_bytes(length=1, byteorder='big', signed=False) + bytes(json.dumps(self.ToDict()), encoding='utf-8')
+        # return self._blfObjType.to_bytes(length=1, byteorder='big', signed=False) + bytes(json.dumps(self.ToDict()), encoding='utf-8')
+        return self._blfObjType.to_bytes(length=1, byteorder='big', signed=False) + orjson.dumps(self.ToDict())
 
     def Data(self) -> typing.List[int]:
         '''
@@ -453,7 +487,8 @@ class CanFdMessage64Py(BlfIoStruct):
         return 'CanFdMessage64'
 
     def DirStr(self) -> str:
-        return self.INDEX_MAP_DIR_STR[self.dir]
+        dir_ = self.dir & 0x01
+        return self.INDEX_MAP_DIR_STR[dir_]
 
 class CanMessagePy(BlfIoStruct):
     _fields_ =[
@@ -919,7 +954,9 @@ class EthernetFramePy(BlfIoStruct):
 
     def Feature(self) -> typing.Tuple:
         # return super().Feature()
-        return (self._blfObjType, self.sourceAddress, self.destinationAddress, self.channel)
+        src_address = ':'.join([hex(item) for item in list(ctypes.string_at(self.sourceAddress, 6))])
+        dst_address = ':'.join([hex(item) for item in list(ctypes.string_at(self.destinationAddress, 6))])
+        return (self._blfObjType, src_address, dst_address, self.channel)
 
     def SourceAddress(self) -> typing.List[int]:
         '''
@@ -937,13 +974,13 @@ class EthernetFramePy(BlfIoStruct):
         '''
         获取源地址的 str 形式
         '''
-        return ':'.join(['{0}'.format(x_) for x_ in self.SourceAddress()])
+        return ':'.join(['{0}'.format(hex(x_)) for x_ in self.SourceAddress()])
 
     def DestinationAddressStr(self) -> str:
         '''
         获取目的地址的 str 形式
         '''
-        return ':'.join(['{0}'.format(x_) for x_ in self.DestinationAddress()])
+        return ':'.join(['{0}'.format(hex(x_)) for x_ in self.DestinationAddress()])
 
     def TypeStr(self) -> str:
         return 'EtherentFrame'
@@ -993,9 +1030,9 @@ class SomeIpFramePy(BlfIoStruct) :
             self,
             proto:str = str(),
             src_ip :str = str(),
-            src_port :str = str(),
+            src_port :int = 0,
             dest_ip :str = str(),
-            dest_port :str = str(),
+            dest_port :int = 0,
             if_type :str = str(),
             srv_id :int = 0,
             srv_name :str = str(),
@@ -1077,7 +1114,7 @@ class SomeIpFramePy(BlfIoStruct) :
         return 'SomeIpMessage'
 
     def DirStr(self) -> str:
-        return self.INDEX_MAP_DIR_STR[self.dir]
+        return self.dir
 
 class SomeIpSDFramePy(BlfIoStruct) :
     INDEX_MAP_DIR_STR = ['tx', 'rx']
@@ -1085,15 +1122,15 @@ class SomeIpSDFramePy(BlfIoStruct) :
             self,
             proto:str = str(),
             src_ip :str = str(),
-            src_port :str = str(),
+            src_port :int = 0,
             dest_ip :str = str(),
-            dest_port :str = str(),
+            dest_port :int = 0,
             dir:str = str(),
             children:dict = dict(),
             data:list = list()
         ) -> None:
         super().__init__()
-        self.proto = proto,
+        self.proto = proto
         self.src_ip = src_ip
         self.src_port = src_port
         self.dest_ip =dest_ip
@@ -1130,6 +1167,6 @@ class SomeIpSDFramePy(BlfIoStruct) :
         return 'SomeIpSDMessage'
 
     def DirStr(self) -> str:
-        return self.INDEX_MAP_DIR_STR[self.dir]
+        return self.dir
 
 
