@@ -1,11 +1,11 @@
 import json
+import os
 import typing
 
 import grpc
 
 from . import ZoneSenderData
 from .ObjIo import *
-
 from .Protos import CanParserNode_pb2, CanParserNode_pb2_grpc
 
 
@@ -171,4 +171,52 @@ class CanParserNodeClient(object):
             return res_.result.result
         except Exception as e_:
             print('GetCanDbInfo Exception: ', e_)
-            return 1000
\ No newline at end of file
+            return 1000
+
+    def ConvertCanDbToPy(self, src_file:str, dst_file:str) -> int:
+        '''
+        将指定的 CANDB 文件转换成 .py 的代码提示辅助文件
+        :param src_file:str 输入的文件, 支持两种类型: CANxxx.arxml 和 CANxxx.json, 支持输入相对路径和绝对路径
+        :param dst_file:str 输出的文件, 将转换的文件写到哪里。注意 python 的 import 不支持 . 和 -
+        :return:int 返回结果 0 成功 其他失败
+        '''
+        try:
+            if (not os.path.isabs(src_file)):
+                src_file = os.path.abspath(src_file)
+            if (not os.path.isabs(dst_file)):
+                dst_file = os.path.abspath(dst_file)
+            res_ = self._canDbParserStub.ConvertCanDbToPy(
+                CanParserNode_pb2.convert_input(
+                    src_file = src_file,
+                    dst_file = dst_file,
+                )
+            )
+            print('ConvertCanDbToPyClient result: {0}, reason: {1}'.format(res_.result, res_.reason))
+            return res_.result
+        except Exception as e_:
+            print('ConvertCanDbToPyClient Exception: ', e_)
+            return 1000
+
+    def ConvertCanDbToJson(self, src_file:str, dst_file:str) -> int:
+        '''
+        将指定的 CANDB 文件转换成 .json 的方便看里面内容的文件
+        :param src_file:str 输入的文件, 支持类型: CANxxx.arxml
+        :param dst_file:str 输出的文件, 将转换的文件写到哪里, 建议使用 .json 后缀
+        :return:int 返回结果 0 成功 其他失败
+        '''
+        try:
+            if (not os.path.isabs(src_file)):
+                src_file = os.path.abspath(src_file)
+            if (not os.path.isabs(dst_file)):
+                dst_file = os.path.abspath(dst_file)
+            res_ = self._canDbParserStub.ConvertCanDbToJson(
+                CanParserNode_pb2.convert_input(
+                    src_file = src_file,
+                    dst_file = dst_file,
+                )
+            )
+            print('ConvertCanDbToJsonClient result: {0}, reason: {1}'.format(res_.result, res_.reason))
+            return res_.result
+        except Exception as e_:
+            print('ConvertCanDbToJsonClient Exception: ', e_)
+            return 1000
