@@ -31,4 +31,4 @@ class CanMessage(ZoneSenderObject):
 
     def __str__(self) -> str:
         # return super().__str__()
-        return 'arbitration_id: {0} data: {1}'.format(hex(self.arbitration_id).upper(), self.data)
+        return 'arbitration_id: {0} data: {1}'.format(hex(self.arbitration_id).upper(), [hex(x_) for x_ in self.data])
