@@ -20,6 +20,19 @@ LOG_REPLAY_NODE_PORT = 6007
 PROCESS_NODE_IP = '127.0.0.1'
 PROCESS_NODE_PORT = 6008
 
+CAN_UDS_NODE_IP = '127.0.0.1'
+CAN_UDS_NODE_PORT = 6009
+
+TCPIP_STACK_NODE_IP = '127.0.0.1'
+TCPIP_STACK_NODE_PORT = 6010
+
+CONFIG_NODE_IP = '127.0.0.1'
+CONFIG_NODE_PORT = 6011
+
+DOIP_UDS_NODE_IP = '127.0.0.1'
+DOIP_UDS_NODE_PORT = 6012
+
+
 GRPC_OPTIONS = [
     ('grpc.max_send_message_length', GRPC_MAX_MESSAGE_LENGTH),
     ('grpc.max_receive_message_length', GRPC_MAX_MESSAGE_LENGTH),
