@@ -15,6 +15,7 @@ from . import ZoneSenderData
 from .ObjIo import *
 from .ZoneSenderFramework import ZoneSenderFramework
 from .SharedMemory import SharedMemZoneSender
+import platform
 
 
 class ZoneSenderStone(ZoneSenderFramework):
@@ -29,7 +30,8 @@ class ZoneSenderStone(ZoneSenderFramework):
         self._mqttClient.on_message = self._OnMqttMessage
         self._mqttClient.on_disconnect = self._OnMqttDisconnect
         self._mqttClient.connect(ZoneSenderData.MQTT_BROKER_IP, ZoneSenderData.MQTT_BROKER_PORT)
-        self.shareMem = SharedMemZoneSender()
+        if platform.system() == 'Windows' :
+            self.shareMem = SharedMemZoneSender()
         self._mqttClient.loop_start()
         
     def Subscribe(self, obj) -> None:
@@ -95,6 +97,7 @@ class ZoneSenderStone(ZoneSenderFramework):
                 return
             self._mqttClient.subscribe('zonesender/someipnode/someippackage/{0}'.format(obj_.serviceName))
             self._mqttClient.subscribe('zonesender/someipnode/someipcalling/{0}'.format(obj_.serviceName))
+            self._mqttClient.subscribe('zonesender/someipnode/someipbypass/{0}'.format(obj_.serviceName))
             self._mqttClient.publish(
                 topic='zonesender/someipnode/subscribe',
                 payload=json.dumps({
@@ -135,7 +138,39 @@ class ZoneSenderStone(ZoneSenderFramework):
                     'type': 'signal',
                 }).encode('utf-8')
             )
-            
+        elif isinstance(obj_, DiagnosticEcuInfo):
+            print("DiagnosticEcuInfo")
+            self._mqttClient.subscribe('zonesender/canudsnode/Rx/diagnostic_request')
+            self._mqttClient.subscribe('zonesender/canudsnode/Rx/diagnostic_response')
+            self._mqttClient.publish(
+                topic='zonesender/canudsnode/subscribe',
+                payload=json.dumps(
+                    {
+                        'client_id': self._mqttClient._client_id.decode('utf-8'),
+                        'channel': obj_.channel,
+                        'name': obj_.name,
+                        'request_id_phys': obj_.request_id,
+                        'response_id': obj_.response_id,
+                        'function_id': obj_.function_id
+                    }
+                )
+            )
+        elif isinstance(obj_, DiagnosticEcuInfo_DoIP):
+            print("DiagnosticEcuInfo_DoIP unsubscribe")
+            self._mqttClient.subscribe('zonesender/doipudsnode/Rx/diagnostic_request')
+            self._mqttClient.subscribe('zonesender/doipudsnode/Rx/diagnostic_response')
+            self._mqttClient.publish(
+                topic='zonesender/doipudsnode/subscribe',
+                payload=json.dumps(
+                    {
+                        'client_id': self._mqttClient._client_id.decode('utf-8'),
+                        'name': obj_.name,
+                        'source_address': obj_.source_address,
+                        'target_address': obj_.target_address
+                    }
+                )
+            )
+
     def UnSubscribe(self, obj) -> None:
         ''' 取消订阅事件，调用该函数后，将不会再 OnXXX 的回调函数中收到相关消息
 
@@ -233,6 +268,38 @@ class ZoneSenderStone(ZoneSenderFramework):
                     'type': 'signal',
                 }).encode('utf-8')
             )
+        elif isinstance(obj_, DiagnosticEcuInfo):
+            print("DiagnosticEcuInfo unsubscribe")
+            self._mqttClient.unsubscribe('zonesender/canudsnode/Rx/diagnostic_request')
+            self._mqttClient.unsubscribe('zonesender/canudsnode/Rx/diagnostic_response')
+            self._mqttClient.publish(
+                topic='zonesender/canudsnode/unsubscribe',
+                payload=json.dumps(
+                    {
+                        'client_id': self._mqttClient._client_id.decode('utf-8'),
+                        'channel': obj_.channel,
+                        'name': obj_.name,
+                        'request_id_phys': obj_.request_id,
+                        'response_id': obj_.response_id,
+                        'function_id': obj_.function_id
+                    }
+                )
+            )
+        elif isinstance(obj_, DiagnosticEcuInfo_DoIP):
+            print("DiagnosticEcuInfo_DoIP unsubscribe")
+            self._mqttClient.unsubscribe('zonesender/doipudsnode/Rx/diagnostic_request')
+            self._mqttClient.unsubscribe('zonesender/doipudsnode/Rx/diagnostic_response')
+            self._mqttClient.publish(
+                topic='zonesender/doipudsnode/unsubscribe',
+                payload=json.dumps(
+                    {
+                        'client_id': self._mqttClient._client_id.decode('utf-8'),
+                        'name': obj_.name,
+                        'source_address': obj_.source_address,
+                        'target_address': obj_.target_address
+                    }
+                )
+            )
 
     def OnCanFrame(self, timestamp , can_frame: 'CanFrame') -> None:
         ''' [需要用户重写实现定制功能]\n
@@ -261,6 +328,38 @@ class ZoneSenderStone(ZoneSenderFramework):
         '''
         pass
 
+    def OnDiagRequest_DoIP(self, diagnostic_request: DoIPDiagMessage):
+        '''[需要用户重写实现定制功能]
+        当收到一个DoIP诊断请求命令 应该做什么，此函数在收到任何订阅过的DoIP诊断请求的时候触发
+        ：param diagnostic_request: 收到诊断请求的报文，包括target_address和诊断TP数据
+        例如target_address：0x1000 cmd:[0x10, 0x01]
+        '''
+        pass
+
+    def OnDiagResponse_DoIP(self, diagnostic_response: DoIPDiagMessage):
+        '''[需要用户重写实现定制功能]
+        当收到一个DoIP诊断请求命令 应该做什么，此函数在收到任何订阅过的DoIP诊断请求的时候触发
+        ：param diagnostic_request: 收到诊断请求的报文，包括target_address和诊断TP数据
+        例如target_address：0x0e80 cmd:[0x50, 0x01]
+        '''
+        pass
+
+    def OnDiagRequest(self, diagnostic_request: CanDiagMessage):
+        ''' [需要用户重写实现定制功能]
+        当收到一个 CAN 诊断请求命令 应该做什么，此函数在收到任何订阅过的CAN 诊断请求的时候触发
+        ：param diagnostic_request: 收到的诊断请求的报文，包括id和诊断TP数据
+        例如 id：0x710 cmd: [0x10, 0x01]
+        '''
+        pass
+
+    def OnDiagResponse(self, diagnostic_response: CanDiagMessage):
+        '''[需要用户重写实现定制功能]
+        当收到一个 CAN 诊断请求命令 应该做什么，此函数在收到任何订阅过的CAN 诊断请求的时候触发
+        ：param diagnostic_request: 收到的诊断请求的报文，包括id和诊断TP数据
+        例如 id：0x718 cmd: [0x50, 0x01]
+        '''
+        pass
+
     def OnCanMessage(self, timestamp, can_message: 'CanMessage') -> None:
         ''' [需要用户重写实现定制功能]\n
         当收到一个 CAN Message 应该做什么，此函数在收到任何订阅过的 CAN Message 的时候触发
@@ -279,7 +378,7 @@ class ZoneSenderStone(ZoneSenderFramework):
         '''
         pass
 
-    def OnSomeipCalling(self, timestamp, someip_in, someip_out) -> None:
+    def OnSomeipCalling(self, timestamp, someip_in: SomeipPackage, someip_out: SomeipPackage, is_response:bool = True) -> None:
         ''' [需要用户重写实现定制功能]\n
         作为 Provider 端调用，当收到 Someip Consumer 的请求做什么\n
         根据 someip_in 的数据做逻辑判断，给 someip_out.context 赋值实现自定义返回数据\n
@@ -287,9 +386,19 @@ class ZoneSenderStone(ZoneSenderFramework):
         :param timestamp: flaot 收到该数据的时间戳,ns
         :param someip_in: ZoneSender.ObjIo.SomeipPackage Someip Consumer 端请求的数据
         :param someip_out: ZoneSender.ObjIp.SomeipPackage 需要填充的数据
+        :param is_response:bool 是否恢复本次 request
         '''
         pass
     
+    def OnSomeipBypass(self,timestamp,someip_package :'SomeipPackage') -> None :
+        ''' [需要用户重写实现定制功能]\n
+        当收到一个 SomeipPackage 应该做什么，此函数在收到任何订阅过的 SomeipPackage 的时候触发
+
+        :param timestamp: 收到该数据的时间戳,ns
+        :param someip_package: ZoneSender.ObjIo.SomeipPackage 收到的 SomeipPackage 对象
+        '''
+        pass
+
     def OnSomeipStateChange(self,timestamp,service : 'tuple',state : 'bool') -> None :
         ''' [需要用户重写实现定制功能]\n
         订阅的服务状态回调
@@ -515,13 +624,13 @@ class ZoneSenderStone(ZoneSenderFramework):
                 'id':obj.id,
                 'name' :obj.name,
                 }
-            if obj.context != None:
+            if obj.context:
                 d_['data'] = obj.context
                 d_['encode_type'] = 'unraw'
-            elif obj.context_raw != None:
+            elif obj.context_raw:
                 d_['data'] = obj.context_raw
                 d_['encode_type'] = 'raw'
-            elif obj.data != None:
+            elif obj.data:
                 d_['data'] = obj.data
             self._mqttClient.publish(
                     topic='zonesender/linparsernode/requests/set_frame_data',
@@ -546,6 +655,66 @@ class ZoneSenderStone(ZoneSenderFramework):
                     payload=json.dumps(d_).encode('utf-8')
                 )
 
+    def diag_request_doip(self, obj):
+        if isinstance(obj, DoIPDiagMessage):
+            d_ = {
+                'target_address': obj.target_address,
+                'header_type': obj.type,
+                'd': obj.cmd,
+            }
+            self._mqttClient.publish(
+                topic='zonesender/doipudsnode/Tx/diagnostic_request',
+                payload=json.dumps(d_).encode('utf-8')
+            )
+
+    def diag_response_doip(self, obj):
+        if isinstance(obj, DoIPDiagMessage):
+            d_ = {
+                'target_address': obj.target_address,
+                'header_type': obj.type,
+                'd': obj.cmd,
+            }
+            self._mqttClient.publish(
+                topic='zonesender/doipudsnode/Tx/diagnostic_response',
+                payload=json.dumps(d_).encode('utf-8')
+            )
+
+    def diag_request(self, obj):
+        if isinstance(obj, CanDiagMessage):
+            d_ = {
+                'id': obj.id,
+                'd': obj.cmd,
+                'dlc': obj.dlc,
+                'fd': obj.is_fd,
+            }
+            self._mqttClient.publish(
+                topic='zonesender/canudsnode/Tx/diagnostic_request',
+                payload=json.dumps(d_).encode('utf-8')
+            )
+
+    def diag_response(self, obj):
+        if isinstance(obj, CanDiagMessage):
+            d_ = {
+                'id': obj.id,
+                'd': obj.cmd,
+                'dlc': obj.dlc,
+                'fd': obj.is_fd
+            }
+            self._mqttClient.publish(
+                topic='zonesender/canudsnode/Tx/diagnostic_response',
+                payload=json.dumps(d_).encode('utf-8')
+            )
+
+    def OnRecvLogMessage(self, log_msg: str) -> None:
+        '''
+        当收到后端的一些 log 信息做什么
+        默认是打印
+        用户可以通过重写该该函数实现定制功能,如：
+        - 屏蔽 log
+        - 写 log 到文件
+        '''
+        print(log_msg)
+
     def _OnMqttMessage(self, client: mqtt.Client, userdata, msg: mqtt.MQTTMessage) -> None:
         '''当收到MQTTMwssage的时候做什么
 
@@ -574,7 +743,7 @@ class ZoneSenderStone(ZoneSenderFramework):
                 # 收到CANPdu
                 self._DealWithCanISignalIPdu(recv_d_)
         elif (topic_split_[1] == 'out'):
-            print(msg.payload.decode('utf-8'))
+            self.OnRecvLogMessage(msg.payload.decode('utf-8'))
         elif (topic_split_[1] == 'someipnode'):
             recv_d_ = json.loads(msg.payload.decode('utf-8'))
             if (topic_split_[2] == 'someippackage'):
@@ -584,6 +753,8 @@ class ZoneSenderStone(ZoneSenderFramework):
             elif (topic_split_[2] == 'someipcalling'):
                 # 作为 Provider 端收到 Someip Request 后做什么
                 self._DealWithSomeipCalling(recv_d_)
+            elif (topic_split_[2] == 'someipbypass') :
+                self._DealWithSomeipBypass(recv_d_)
             elif (topic_split_[2] == 'statechange') :
                 self.OnSomeipStateChange(recv_d_['t'],(recv_d_['srv_id'],recv_d_['inst_id']),recv_d_['state'])   
         elif topic_split_[1] == 'linstacknode' :
@@ -600,6 +771,20 @@ class ZoneSenderStone(ZoneSenderFramework):
                 # 收到CANPdu
                 self._DealWithLinFrame(recv_d_)
 
+        elif topic_split_[1] == 'canudsnode' and topic_split_[2] == 'Rx':
+            recv_d_ = json.loads(msg.payload.decode('utf-8'))
+            if topic_split_[3] == 'diagnostic_request':
+                self._DealWithCanUdsMessageRequest(recv_d_)
+            elif topic_split_[3] == 'diagnostic_response':
+                self._DealWithCanUdsMessageResponse(recv_d_)
+
+        elif topic_split_[1] == 'doipudsnode' and topic_split_[2] == 'Rx':
+            recv_d_ = json.loads(msg.payload.decode('utf-8'))
+            if topic_split_[3] == 'diagnostic_request':
+                self._DealWithDoIPUdsMessageRequest(recv_d_)
+            elif topic_split_[3] == 'diagnostic_response':
+                self._DealWithDoIPUdsMessageResponse(recv_d_)
+
     def _OnMqttConnect(self, client: mqtt.Client, userdata, flags, rc) -> None:
         '''
         连接到 MQTT Broker 的时候做什么
@@ -622,6 +807,25 @@ class ZoneSenderStone(ZoneSenderFramework):
                 print(e_)
             time.sleep(2)
 
+    def _DealWithDoIPUdsMessageRequest(self, recv_d: dict):
+        diag_msg_ = DoIPDiagMessage(target_address=recv_d['target_address'], header_type=recv_d['header_type'], cmd=recv_d['d'])
+        self._threadPool.submit(self.OnDiagRequest_DoIP, diag_msg_)
+
+    def _DealWithDoIPUdsMessageResponse(self, recv_d: dict):
+        print("_DealWithDoIPUdsMessageResponse", recv_d)
+        diag_msg_ = DoIPDiagMessage(target_address=recv_d['target_address'], header_type=recv_d['header_type'], cmd=recv_d['d'])
+        self._threadPool.submit(self.OnDiagResponse_DoIP, diag_msg_)
+
+    def _DealWithCanUdsMessageRequest(self, recv_d: dict):
+        '''处理接收到的诊断请求消息'''
+        diag_msg_ = CanDiagMessage(id=recv_d['id'], cmd=recv_d['d'])
+        self._threadPool.submit(self.OnDiagRequest, diag_msg_)
+
+    def _DealWithCanUdsMessageResponse(self, recv_d: dict):
+        '''处理接收到的诊断响应消息'''
+        diag_msg_ = CanDiagMessage(id=recv_d['id'], cmd=recv_d['d'])
+        self._threadPool.submit(self.OnDiagResponse, diag_msg_)
+
     def _DealWithCanMessage(self, recv_d: 'dict') -> None:
         '''
         处理接收到的 CaneMessage 消息
@@ -661,7 +865,8 @@ class ZoneSenderStone(ZoneSenderFramework):
         '''
         can_pdu_ = CanISignalIPdu(
             name=recv_d['name'],
-            channel=recv_d['chl']
+            channel=recv_d['chl'],
+            context=recv_d['cnt'],
         )
         can_pdu_.data = recv_d['d']
         self._threadPool.submit(
@@ -758,3 +963,13 @@ class ZoneSenderStone(ZoneSenderFramework):
             self.OnLinSignal,
             recv_d['t'], lin_signal_
         )
+
+    def _DealWithSomeipBypass(self, recv_d: 'dict') -> None:
+        '''
+        处理接收到的 SomeipBypass
+        '''
+        recv_d['payload'] = bytes.fromhex(recv_d['payload'])
+        self._threadPool.submit(
+            self.OnSomeipBypass,
+            recv_d['t'], SomeipPackage.From(recv_d)
+        )
